ProcessingModule

Struct ProcessingModule 

pub struct ProcessingModule<Processor> { /* private fields */ }
Represents collector of records. This module is responsible for receiving events and saving them using various means. Processing module is only responsible for managing the lifecycle, and doesn’t handele any data saving itself. Data saving is done through EventProcessor.

Implementations

Source

impl<P: EventProcessor> ProcessingModule<P>

pub fn new(receiver: Receiver<RecordEvent>, processor: P) -> Self

pub async fn run(self) -> Result<()>