pub struct ProcessingModule<Processor> { /* private fields */ }Expand description
Represents collector of records. This module is responsible for receiving events and saving them using various means. Processing module is only responsible for managing the lifecycle, and doesn’t handele any data saving itself. Data saving is done through EventProcessor.
Implementations
Sourceimpl<P: EventProcessor> ProcessingModule<P>
impl<P: EventProcessor> ProcessingModule<P>